@@ -22,13 +22,15 @@
 
 #include <QApplication>
 
-#include <KLocalizedString>
-
-static const KLocalizedString description = ki18n("KDE Bluetooth System");
-
 int main(int argc, char *argv[])
 {
+    if (argc < 2) {
+        fprintf(stderr, "Usage: bluedevil-requestpin device-name [numeric]\n");
+        return 2;
+    }
+
     QApplication app(argc, argv);
+    app.setAttribute(Qt::AA_UseHighDpiPixmaps);
     app.setApplicationName(QStringLiteral("bluedevil"));
     app.setOrganizationDomain(QStringLiteral("kde.org"));
 
