@@ -22,24 +22,24 @@
 
 #include "keyboardpairing.h"
 #include "wizardagent.h"
-#include "bluewizard.h"
+#include "../bluewizard.h"
 #include "debug_p.h"
 
-#include <QDebug>
+#include <KIconLoader>
+#include <KPixmapSequence>
+#include <KPixmapSequenceOverlayPainter>
 
-#include <kiconloader.h>
-#include <kpixmapsequence.h>
-#include <kpixmapsequenceoverlaypainter.h>
+#include <BluezQt/Device>
+#include <BluezQt/Adapter>
+#include <BluezQt/PendingCall>
 
-#include <bluedevil/bluedevil.h>
-
-using namespace BlueDevil;
-
-KeyboardPairingPage::KeyboardPairingPage(BlueWizard* parent)
+KeyboardPairingPage::KeyboardPairingPage(BlueWizard *parent)
     : QWizardPage(parent)
     , m_wizard(parent)
+    , m_success(false)
 {
     setupUi(this);
+
     m_working = new KPixmapSequenceOverlayPainter(this);
     m_working->setSequence(KIconLoader::global()->loadPixmapSequence(QStringLiteral("process-working"), 22));
     m_working->setWidget(pinNumber);
@@ -51,16 +51,43 @@ KeyboardPairingPage::KeyboardPairingPage(BlueWizard* parent)
     pinNumber->setFont(font);
 }
 
+int KeyboardPairingPage::nextId() const
+{
+    if (m_success) {
+        return BlueWizard::Connect;
+    }
+    return BlueWizard::Fail;
+}
+
 void KeyboardPairingPage::initializePage()
 {
-    qCDebug(WIZARD);
+    qCDebug(WIZARD) << "Initialize Keyboard Pairing Page";
+
     m_wizard->setButtonLayout(wizardButtonsLayout());
 
-    connect(m_wizard->agent(), SIGNAL(pinRequested(QString)), this, SLOT(pinRequested(QString)));
+    connect(m_wizard->agent(), &WizardAgent::pinRequested, this, &KeyboardPairingPage::pinRequested);
 
-    Device *device = m_wizard->device();
-    connect(device, SIGNAL(pairedChanged(bool)), this, SLOT(pairedChanged(bool)));
-    device->pair();
+    // Adapter must be pairable, otherwise pairing would fail
+    BluezQt::PendingCall *call = m_wizard->device()->adapter()->setPairable(true);
+    connect(call, &BluezQt::PendingCall::finished, this, &KeyboardPairingPage::setPairableFinished);
+}
+
+void KeyboardPairingPage::setPairableFinished(BluezQt::PendingCall *call)
+{
+    Q_UNUSED(call)
+
+    BluezQt::PendingCall *pairCall = m_wizard->device()->pair();
+    connect(pairCall, &BluezQt::PendingCall::finished, this, &KeyboardPairingPage::pairingFinished);
+}
+
+void KeyboardPairingPage::pairingFinished(BluezQt::PendingCall *call)
+{
+    qCDebug(WIZARD) << "Keyboard Pairing finished:";
+    qCDebug(WIZARD) << "\t error     : " << (bool) call->error();
+    qCDebug(WIZARD) << "\t errorText : " << call->errorText();
+
+    m_success = !call->error();
+    wizard()->next();
 }
 
 void KeyboardPairingPage::pinRequested(const QString& pin)
@@ -69,27 +96,10 @@ void KeyboardPairingPage::pinRequested(const QString& pin)
     pinNumber->setText(pin);
 }
 
-void KeyboardPairingPage::pairedChanged(bool paired)
-{
-    qCDebug(WIZARD) << paired;
-    m_wizard->next();
-}
-
-bool KeyboardPairingPage::validatePage()
-{
-    return m_wizard->device()->isPaired();
-}
-
-int KeyboardPairingPage::nextId() const
-{
-    return BlueWizard::Connect;
-}
-
 QList<QWizard::WizardButton> KeyboardPairingPage::wizardButtonsLayout() const
 {
     QList <QWizard::WizardButton> list;
     list << QWizard::Stretch;
     list << QWizard::CancelButton;
-
     return list;
 }
