@@ -24,39 +24,38 @@
 #define LEGACYPAIRING_H
 
 #include "ui_legacypairing.h"
+
 #include <QWizardPage>
 
+namespace BluezQt
+{
+    class PendingCall;
+}
+
 class BlueWizard;
 class KPixmapSequenceOverlayPainter;
 
-namespace BlueDevil {
-    class Device;
-    class Adapter;
-}
-
-using namespace BlueDevil;
-
 class LegacyPairingPage : public QWizardPage, Ui::LegacyPairing
 {
-Q_OBJECT
+    Q_OBJECT
 
 public:
-    LegacyPairingPage(BlueWizard* parent = 0);
+    explicit LegacyPairingPage(BlueWizard *parent = 0);
 
-    virtual void initializePage();
-    virtual bool validatePage();
-    virtual int nextId() const;
+    int nextId() const Q_DECL_OVERRIDE;
+    void initializePage() Q_DECL_OVERRIDE;
 
 public Q_SLOTS:
+    void setPairableFinished(BluezQt::PendingCall *call);
+    void pairingFinished(BluezQt::PendingCall *call);
     void pinRequested(const QString &pin);
-    void pairedChanged(bool paired);
-
-protected:
-    QList <QWizard::WizardButton> wizardButtonsLayout() const;
 
 private:
-    BlueWizard                    *m_wizard;
+    QList <QWizard::WizardButton> wizardButtonsLayout() const;
+
+    BlueWizard *m_wizard;
     KPixmapSequenceOverlayPainter *m_working;
+    bool m_success;
 };
 
 #endif // LEGACYPAIRING_H
